@@ -667,13 +667,13 @@ public class TestRepository<R extends Repository> {
 				pw.release();
 			}
 
-			odb.openPack(pack, idx);
+			odb.openPack(pack);
 			updateServerInfo();
 			prunePacked(odb);
 		}
 	}
 
-	private void prunePacked(ObjectDirectory odb) throws IOException {
+	private static void prunePacked(ObjectDirectory odb) throws IOException {
 		for (PackFile p : odb.getPacks()) {
 			for (MutableEntry e : p)
 				FileUtils.delete(odb.fileFor(e.toObjectId()));
