@@ -48,11 +48,13 @@
 
 package org.eclipse.jgit.pgm;
 
+import java.text.MessageFormat;
 import java.util.List;
 
 import org.eclipse.jgit.api.Git;
 import org.eclipse.jgit.api.ListTagCommand;
 import org.eclipse.jgit.api.TagCommand;
+import org.eclipse.jgit.api.errors.RefAlreadyExistsException;
 import org.eclipse.jgit.lib.ObjectId;
 import org.eclipse.jgit.lib.Ref;
 import org.eclipse.jgit.lib.Repository;
@@ -66,7 +68,7 @@ class Tag extends TextBuiltin {
 	private boolean force;
 
 	@Option(name = "-m", metaVar = "metaVar_message", usage = "usage_tagMessage")
-	private String message = "";
+	private String message = ""; //$NON-NLS-1$
 
 	@Argument(index = 0, metaVar = "metaVar_name")
 	private String tagName;
@@ -85,13 +87,17 @@ class Tag extends TextBuiltin {
 				RevWalk walk = new RevWalk(db);
 				command.setObjectId(walk.parseAny(object));
 			}
-
-			command.call();
+			try {
+				command.call();
+			} catch (RefAlreadyExistsException e) {
+				throw die(MessageFormat.format(CLIText.get().tagAlreadyExists,
+						tagName));
+			}
 		} else {
 			ListTagCommand command = git.tagList();
 			List<Ref> list = command.call();
 			for (Ref ref : list) {
-				out.println(Repository.shortenRefName(ref.getName()));
+				outw.println(Repository.shortenRefName(ref.getName()));
 			}
 		}
 	}
