@@ -52,12 +52,13 @@ import static org.junit.Assert.fail;
 import java.io.File;
 import java.util.Iterator;
 
+import org.eclipse.jgit.api.MergeCommand.FastForwardMode;
 import org.eclipse.jgit.api.MergeResult.MergeStatus;
 import org.eclipse.jgit.api.errors.InvalidMergeHeadsException;
+import org.eclipse.jgit.junit.RepositoryTestCase;
 import org.eclipse.jgit.lib.Constants;
 import org.eclipse.jgit.lib.Ref;
 import org.eclipse.jgit.lib.RepositoryState;
-import org.eclipse.jgit.lib.RepositoryTestCase;
 import org.eclipse.jgit.merge.MergeStrategy;
 import org.eclipse.jgit.merge.ResolveMerger.MergeFailureReason;
 import org.eclipse.jgit.revwalk.RevCommit;
@@ -461,7 +462,7 @@ public class MergeCommandTest extends RepositoryTestCase {
 
 		assertEquals(null, result.getConflicts());
 
-		assertTrue(2 == result.getMergedCommits().length);
+		assertEquals(2, result.getMergedCommits().length);
 		assertEquals(thirdCommit, result.getMergedCommits()[0]);
 		assertEquals(secondCommit, result.getMergedCommits()[1]);
 
@@ -523,7 +524,7 @@ public class MergeCommandTest extends RepositoryTestCase {
 
 		assertEquals(null, result.getConflicts());
 
-		assertTrue(2 == result.getMergedCommits().length);
+		assertEquals(2, result.getMergedCommits().length);
 		assertEquals(thirdCommit, result.getMergedCommits()[0]);
 		assertEquals(secondCommit, result.getMergedCommits()[1]);
 
@@ -1328,17 +1329,68 @@ public class MergeCommandTest extends RepositoryTestCase {
 		assertEquals(StatusCommandTest.set("file2"), stat.getConflicting());
 	}
 
-	private void setExecutable(Git git, String path, boolean executable) {
+	@Test
+	public void testFastForwardOnly() throws Exception {
+		Git git = new Git(db);
+		RevCommit initialCommit = git.commit().setMessage("initial commit")
+				.call();
+		createBranch(initialCommit, "refs/heads/branch1");
+		git.commit().setMessage("second commit").call();
+		checkoutBranch("refs/heads/branch1");
+
+		MergeCommand merge = git.merge();
+		merge.setFastForward(FastForwardMode.FF_ONLY);
+		merge.include(db.getRef(Constants.MASTER));
+		MergeResult result = merge.call();
+
+		assertEquals(MergeStatus.FAST_FORWARD, result.getMergeStatus());
+	}
+	@Test
+	public void testNoFastForward() throws Exception {
+		Git git = new Git(db);
+		RevCommit initialCommit = git.commit().setMessage("initial commit")
+				.call();
+		createBranch(initialCommit, "refs/heads/branch1");
+		git.commit().setMessage("second commit").call();
+		checkoutBranch("refs/heads/branch1");
+
+		MergeCommand merge = git.merge();
+		merge.setFastForward(FastForwardMode.NO_FF);
+		merge.include(db.getRef(Constants.MASTER));
+		MergeResult result = merge.call();
+
+		assertEquals(MergeStatus.MERGED, result.getMergeStatus());
+	}
+
+	@Test
+	public void testFastForwardOnlyNotPossible() throws Exception {
+		Git git = new Git(db);
+		RevCommit initialCommit = git.commit().setMessage("initial commit")
+				.call();
+		createBranch(initialCommit, "refs/heads/branch1");
+		git.commit().setMessage("second commit").call();
+		checkoutBranch("refs/heads/branch1");
+		writeTrashFile("file1", "branch1");
+		git.add().addFilepattern("file").call();
+		git.commit().setMessage("second commit on branch1").call();
+		MergeCommand merge = git.merge();
+		merge.setFastForward(FastForwardMode.FF_ONLY);
+		merge.include(db.getRef(Constants.MASTER));
+		MergeResult result = merge.call();
+
+		assertEquals(MergeStatus.ABORTED, result.getMergeStatus());
+	}
+	private static void setExecutable(Git git, String path, boolean executable) {
 		FS.DETECTED.setExecute(
 				new File(git.getRepository().getWorkTree(), path), executable);
 	}
 
-	private boolean canExecute(Git git, String path) {
+	private static boolean canExecute(Git git, String path) {
 		return FS.DETECTED.canExecute(new File(git.getRepository()
 				.getWorkTree(), path));
 	}
 
-	private RevCommit addAllAndCommit(final Git git) throws Exception {
+	private static RevCommit addAllAndCommit(final Git git) throws Exception {
 		git.add().addFilepattern(".").call();
 		return git.commit().setMessage("message").call();
 	}
