@@ -54,11 +54,11 @@ import java.text.MessageFormat;
 import org.eclipse.jgit.api.errors.InvalidRefNameException;
 import org.eclipse.jgit.api.errors.JGitInternalException;
 import org.eclipse.jgit.api.errors.NoHeadException;
-import org.eclipse.jgit.errors.CheckoutConflictException;
+import org.eclipse.jgit.api.errors.StashApplyFailureException;
 import org.eclipse.jgit.internal.JGitText;
+import org.eclipse.jgit.junit.RepositoryTestCase;
 import org.eclipse.jgit.lib.ObjectId;
 import org.eclipse.jgit.lib.Repository;
-import org.eclipse.jgit.lib.RepositoryTestCase;
 import org.eclipse.jgit.revwalk.RevCommit;
 import org.eclipse.jgit.util.FileUtils;
 import org.junit.Before;
@@ -314,14 +314,15 @@ public class StashApplyCommandTest extends RepositoryTestCase {
 
 		Status status = git.status().call();
 		assertTrue(status.getAdded().isEmpty());
-		assertTrue(status.getChanged().isEmpty());
+		assertEquals(1, status.getChanged().size());
+		assertTrue(status.getChanged().contains(PATH));
 		assertTrue(status.getConflicting().isEmpty());
-		assertTrue(status.getMissing().isEmpty());
+		assertEquals(1, status.getMissing().size());
+		assertTrue(status.getMissing().contains(PATH));
 		assertTrue(status.getModified().isEmpty());
 		assertTrue(status.getUntracked().isEmpty());
 
-		assertEquals(1, status.getRemoved().size());
-		assertTrue(status.getRemoved().contains(PATH));
+		assertTrue(status.getRemoved().isEmpty());
 	}
 
 	@Test
@@ -366,9 +367,66 @@ public class StashApplyCommandTest extends RepositoryTestCase {
 		try {
 			git.stashApply().call();
 			fail("Exception not thrown");
-		} catch (JGitInternalException e) {
-			assertTrue(e.getCause() instanceof CheckoutConflictException);
+		} catch (StashApplyFailureException e) {
+ 		}
+		assertEquals("content3", read(PATH));
+	}
+
+	@Test
+	public void stashedContentMerge() throws Exception {
+		writeTrashFile(PATH, "content\nmore content\n");
+		git.add().addFilepattern(PATH).call();
+		git.commit().setMessage("more content").call();
+
+		writeTrashFile(PATH, "content\nhead change\nmore content\n");
+		git.add().addFilepattern(PATH).call();
+		git.commit().setMessage("even content").call();
+
+		writeTrashFile(PATH, "content\nstashed change\nmore content\n");
+
+		RevCommit stashed = git.stashCreate().call();
+		assertNotNull(stashed);
+		assertEquals("content\nhead change\nmore content\n",
+				read(committedFile));
+		assertTrue(git.status().call().isClean());
+
+		writeTrashFile(PATH, "content\nmore content\ncommitted change\n");
+		git.add().addFilepattern(PATH).call();
+		git.commit().setMessage("committed change").call();
+
+		try {
+			git.stashApply().call();
+			fail("Expected conflict");
+		} catch (StashApplyFailureException e) {
 		}
+		Status status = new StatusCommand(db).call();
+		assertEquals(1, status.getConflicting().size());
+		assertEquals(
+				"content\n<<<<<<< HEAD\n=======\nstashed change\n>>>>>>> stash\nmore content\ncommitted change\n",
+				read(PATH));
+	}
+
+	@Test
+	public void workingDirectoryContentMerge() throws Exception {
+		writeTrashFile(PATH, "content\nmore content\n");
+		git.add().addFilepattern(PATH).call();
+		git.commit().setMessage("more content").call();
+
+		writeTrashFile(PATH, "content\nstashed change\nmore content\n");
+
+		RevCommit stashed = git.stashCreate().call();
+		assertNotNull(stashed);
+		assertEquals("content\nmore content\n", read(committedFile));
+		assertTrue(git.status().call().isClean());
+
+		writeTrashFile(PATH, "content\nmore content\ncommitted change\n");
+		git.add().addFilepattern(PATH).call();
+		git.commit().setMessage("committed change").call();
+
+		git.stashApply().call();
+		assertEquals(
+				"content\nstashed change\nmore content\ncommitted change\n",
+				read(committedFile));
 	}
 
 	@Test
@@ -387,9 +445,9 @@ public class StashApplyCommandTest extends RepositoryTestCase {
 		try {
 			git.stashApply().call();
 			fail("Exception not thrown");
-		} catch (JGitInternalException e) {
-			assertTrue(e.getCause() instanceof CheckoutConflictException);
+		} catch (StashApplyFailureException e) {
 		}
+		assertEquals("content2", read(PATH));
 	}
 
 	@Test
