@@ -64,12 +64,14 @@ import org.eclipse.jgit.dircache.DirCache;
 import org.eclipse.jgit.dircache.DirCacheEditor;
 import org.eclipse.jgit.dircache.DirCacheEditor.PathEdit;
 import org.eclipse.jgit.dircache.DirCacheEntry;
+import org.eclipse.jgit.junit.RepositoryTestCase;
 import org.eclipse.jgit.merge.MergeStrategy;
 import org.eclipse.jgit.revwalk.RevCommit;
 import org.eclipse.jgit.treewalk.FileTreeIterator;
 import org.eclipse.jgit.util.IO;
 import org.junit.Test;
 
+@SuppressWarnings("deprecation")
 public class IndexDiffTest extends RepositoryTestCase {
 
 	static PathEdit add(final Repository db, final File workdir,
@@ -465,19 +467,23 @@ public class IndexDiffTest extends RepositoryTestCase {
 		git.add().addFilepattern(path).call();
 		String path2 = "file2";
 		writeTrashFile(path2, "content");
-		git.add().addFilepattern(path2).call();
+		String path3 = "file3";
+		writeTrashFile(path3, "some content");
+		git.add().addFilepattern(path2).addFilepattern(path3).call();
 		git.commit().setMessage("commit").call();
 		assumeUnchanged(path2);
+		assumeUnchanged(path3);
 		writeTrashFile(path, "more content");
-		writeTrashFile(path2, "more content");
+		deleteTrashFile(path3);
 
 		FileTreeIterator iterator = new FileTreeIterator(db);
 		IndexDiff diff = new IndexDiff(db, Constants.HEAD, iterator);
 		diff.diff();
-		assertEquals(1, diff.getAssumeUnchanged().size());
+		assertEquals(2, diff.getAssumeUnchanged().size());
 		assertEquals(1, diff.getModified().size());
 		assertEquals(0, diff.getChanged().size());
 		assertTrue(diff.getAssumeUnchanged().contains("file2"));
+		assertTrue(diff.getAssumeUnchanged().contains("file3"));
 		assertTrue(diff.getModified().contains("file"));
 
 		git.add().addFilepattern(".").call();
@@ -485,10 +491,11 @@ public class IndexDiffTest extends RepositoryTestCase {
 		iterator = new FileTreeIterator(db);
 		diff = new IndexDiff(db, Constants.HEAD, iterator);
 		diff.diff();
-		assertEquals(1, diff.getAssumeUnchanged().size());
+		assertEquals(2, diff.getAssumeUnchanged().size());
 		assertEquals(0, diff.getModified().size());
 		assertEquals(1, diff.getChanged().size());
 		assertTrue(diff.getAssumeUnchanged().contains("file2"));
+		assertTrue(diff.getAssumeUnchanged().contains("file3"));
 		assertTrue(diff.getChanged().contains("file"));
 		assertEquals(Collections.EMPTY_SET, diff.getUntrackedFolders());
 	}
