@@ -42,6 +42,7 @@
  */
 package org.eclipse.jgit.storage.file;
 
+import static java.lang.Integer.valueOf;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertSame;
@@ -51,6 +52,7 @@ import java.io.File;
 import java.util.Collection;
 import java.io.IOException;
 import java.util.Collections;
+import java.util.Date;
 import java.util.Iterator;
 import java.util.concurrent.BrokenBarrierException;
 import java.util.concurrent.Callable;
@@ -62,13 +64,14 @@ import java.util.concurrent.TimeUnit;
 
 import org.eclipse.jgit.internal.JGitText;
 import org.eclipse.jgit.junit.LocalDiskRepositoryTestCase;
+import org.eclipse.jgit.junit.RepositoryTestCase;
 import org.eclipse.jgit.junit.TestRepository;
 import org.eclipse.jgit.junit.TestRepository.BranchBuilder;
 import org.eclipse.jgit.lib.Constants;
 import org.eclipse.jgit.junit.TestRepository.CommitBuilder;
+import org.eclipse.jgit.lib.AnyObjectId;
 import org.eclipse.jgit.lib.EmptyProgressMonitor;
 import org.eclipse.jgit.lib.ObjectId;
-import org.eclipse.jgit.lib.RepositoryTestCase;
 import org.eclipse.jgit.lib.Ref.Storage;
 import org.eclipse.jgit.lib.RefUpdate;
 import org.eclipse.jgit.lib.RefUpdate.Result;
@@ -132,9 +135,9 @@ public class GCTest extends LocalDiskRepositoryTestCase {
 				syncPoint.await();
 				try {
 					gc.packRefs();
-					return 0;
+					return valueOf(0);
 				} catch (IOException e) {
-					return 1;
+					return valueOf(1);
 				}
 			}
 		};
@@ -142,7 +145,7 @@ public class GCTest extends LocalDiskRepositoryTestCase {
 		try {
 			Future<Integer> p1 = pool.submit(packRefs);
 			Future<Integer> p2 = pool.submit(packRefs);
-			assertTrue(p1.get() + p2.get() == 1);
+			assertEquals(1, p1.get().intValue() + p2.get().intValue());
 		} finally {
 			pool.shutdown();
 			pool.awaitTermination(Long.MAX_VALUE, TimeUnit.SECONDS);
@@ -255,7 +258,7 @@ public class GCTest extends LocalDiskRepositoryTestCase {
 				try {
 					gc.setProgressMonitor(this);
 					gc.repack();
-					return 0;
+					return valueOf(0);
 				} catch (IOException e) {
 					// leave the syncPoint in broken state so any awaiting
 					// threads and any threads that call await in the future get
@@ -266,7 +269,7 @@ public class GCTest extends LocalDiskRepositoryTestCase {
 					} catch (InterruptedException ignored) {
 						//
 					}
-					return 1;
+					return valueOf(1);
 				}
 			}
 		}
@@ -280,7 +283,7 @@ public class GCTest extends LocalDiskRepositoryTestCase {
 			DoRepack repack2 = new DoRepack();
 			Future<Integer> result1 = pool.submit(repack1);
 			Future<Integer> result2 = pool.submit(repack2);
-			assertTrue(result1.get() + result2.get() == 0);
+			assertEquals(0, result1.get().intValue() + result2.get().intValue());
 		} finally {
 			pool.shutdown();
 			pool.awaitTermination(Long.MAX_VALUE, TimeUnit.SECONDS);
@@ -291,12 +294,8 @@ public class GCTest extends LocalDiskRepositoryTestCase {
 
 	@Test
 	public void nonReferencedNonExpiredObject_notPruned() throws Exception {
-		long start = now();
-
-		fsTick();
 		RevBlob a = tr.blob("a");
-		long delta = now() - start;
-		gc.setExpireAgeMillis(delta);
+		gc.setExpire(new Date(lastModified(a)));
 		gc.prune(Collections.<ObjectId> emptySet());
 		assertTrue(repo.hasObject(a));
 	}
@@ -305,6 +304,7 @@ public class GCTest extends LocalDiskRepositoryTestCase {
 	public void nonReferencedExpiredObject_pruned() throws Exception {
 		RevBlob a = tr.blob("a");
 		gc.setExpireAgeMillis(0);
+		fsTick();
 		gc.prune(Collections.<ObjectId> emptySet());
 		assertFalse(repo.hasObject(a));
 	}
@@ -314,6 +314,7 @@ public class GCTest extends LocalDiskRepositoryTestCase {
 		RevBlob a = tr.blob("a");
 		RevTree t = tr.tree(tr.file("a", a));
 		gc.setExpireAgeMillis(0);
+		fsTick();
 		gc.prune(Collections.<ObjectId> emptySet());
 		assertFalse(repo.hasObject(t));
 		assertFalse(repo.hasObject(a));
@@ -322,13 +323,11 @@ public class GCTest extends LocalDiskRepositoryTestCase {
 	@Test
 	public void nonReferencedObjects_onlyExpiredPruned() throws Exception {
 		RevBlob a = tr.blob("a");
-
-		fsTick();
-		long start = now();
+		gc.setExpire(new Date(lastModified(a) + 1));
 
 		fsTick();
 		RevBlob b = tr.blob("b");
-		gc.setExpireAgeMillis(now() - start);
+
 		gc.prune(Collections.<ObjectId> emptySet());
 		assertFalse(repo.hasObject(a));
 		assertTrue(repo.hasObject(b));
@@ -339,6 +338,7 @@ public class GCTest extends LocalDiskRepositoryTestCase {
 		RevBlob a = tr.blob("a");
 		tr.lightweightTag("t", a);
 		gc.setExpireAgeMillis(0);
+		fsTick();
 		gc.prune(Collections.<ObjectId> emptySet());
 		assertTrue(repo.hasObject(a));
 	}
@@ -350,6 +350,7 @@ public class GCTest extends LocalDiskRepositoryTestCase {
 		tr.lightweightTag("t", t);
 
 		gc.setExpireAgeMillis(0);
+		fsTick();
 		gc.prune(Collections.<ObjectId> emptySet());
 		assertTrue(repo.hasObject(t));
 		assertTrue(repo.hasObject(a));
@@ -360,6 +361,7 @@ public class GCTest extends LocalDiskRepositoryTestCase {
 		RevCommit tip = commitChain(10);
 		tr.branch("b").update(tip);
 		gc.setExpireAgeMillis(0);
+		fsTick();
 		gc.prune(Collections.<ObjectId> emptySet());
 		do {
 			assertTrue(repo.hasObject(tip));
@@ -379,6 +381,7 @@ public class GCTest extends LocalDiskRepositoryTestCase {
 		update.setForceUpdate(true);
 		update.delete();
 		gc.setExpireAgeMillis(0);
+		fsTick();
 		gc.prune(Collections.<ObjectId> emptySet());
 		assertTrue(gc.getStatistics().numberOfLooseObjects == 0);
 	}
@@ -407,6 +410,7 @@ public class GCTest extends LocalDiskRepositoryTestCase {
 		update.delete();
 
 		gc.setExpireAgeMillis(0);
+		fsTick();
 		gc.prune(Collections.<ObjectId> emptySet());
 		assertTrue(repo.hasObject(b2Tip));
 	}
@@ -535,6 +539,7 @@ public class GCTest extends LocalDiskRepositoryTestCase {
 		assertEquals(0, stats.numberOfPackedObjects);
 
 		gc.setExpireAgeMillis(0);
+		fsTick();
 		gc.gc();
 		stats = gc.getStatistics();
 		assertEquals(0, stats.numberOfLooseObjects);
@@ -584,6 +589,7 @@ public class GCTest extends LocalDiskRepositoryTestCase {
 		assertEquals(8, stats.numberOfLooseObjects);
 		assertEquals(0, stats.numberOfPackedObjects);
 		gc.setExpireAgeMillis(0);
+		fsTick();
 		gc.gc();
 		stats = gc.getStatistics();
 		assertEquals(0, stats.numberOfLooseObjects);
@@ -643,6 +649,7 @@ public class GCTest extends LocalDiskRepositoryTestCase {
 		assertEquals(9, stats.numberOfLooseObjects);
 		assertEquals(0, stats.numberOfPackedObjects);
 		gc.setExpireAgeMillis(0);
+		fsTick();
 		gc.gc();
 		stats = gc.getStatistics();
 		assertEquals(0, stats.numberOfLooseObjects);
@@ -660,6 +667,7 @@ public class GCTest extends LocalDiskRepositoryTestCase {
 		stats = gc.getStatistics();
 		assertEquals(8, stats.numberOfLooseObjects);
 		gc.setExpireAgeMillis(0);
+		fsTick();
 		gc.prune(Collections.<ObjectId> emptySet());
 		stats = gc.getStatistics();
 		assertEquals(8, stats.numberOfLooseObjects);
@@ -700,8 +708,8 @@ public class GCTest extends LocalDiskRepositoryTestCase {
 		return tip;
 	}
 
-	private static long now() {
-		return System.currentTimeMillis();
+	private long lastModified(AnyObjectId objectId) {
+		return repo.getObjectDatabase().fileFor(objectId).lastModified();
 	}
 
 	private static void fsTick() throws InterruptedException, IOException {
