@@ -110,38 +110,40 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 	/**
 	 * The name of the "rebase-merge" folder
 	 */
-	public static final String REBASE_MERGE = "rebase-merge";
+	public static final String REBASE_MERGE = "rebase-merge"; //$NON-NLS-1$
 
 	/**
 	 * The name of the "stopped-sha" file
 	 */
-	public static final String STOPPED_SHA = "stopped-sha";
+	public static final String STOPPED_SHA = "stopped-sha"; //$NON-NLS-1$
 
-	private static final String AUTHOR_SCRIPT = "author-script";
+	private static final String AUTHOR_SCRIPT = "author-script"; //$NON-NLS-1$
 
-	private static final String DONE = "done";
+	private static final String DONE = "done"; //$NON-NLS-1$
 
-	private static final String GIT_AUTHOR_DATE = "GIT_AUTHOR_DATE";
+	private static final String GIT_AUTHOR_DATE = "GIT_AUTHOR_DATE"; //$NON-NLS-1$
 
-	private static final String GIT_AUTHOR_EMAIL = "GIT_AUTHOR_EMAIL";
+	private static final String GIT_AUTHOR_EMAIL = "GIT_AUTHOR_EMAIL"; //$NON-NLS-1$
 
-	private static final String GIT_AUTHOR_NAME = "GIT_AUTHOR_NAME";
+	private static final String GIT_AUTHOR_NAME = "GIT_AUTHOR_NAME"; //$NON-NLS-1$
 
-	private static final String GIT_REBASE_TODO = "git-rebase-todo";
+	private static final String GIT_REBASE_TODO = "git-rebase-todo"; //$NON-NLS-1$
 
-	private static final String HEAD_NAME = "head-name";
+	private static final String HEAD_NAME = "head-name"; //$NON-NLS-1$
 
-	private static final String INTERACTIVE = "interactive";
+	private static final String INTERACTIVE = "interactive"; //$NON-NLS-1$
 
-	private static final String MESSAGE = "message";
+	private static final String MESSAGE = "message"; //$NON-NLS-1$
 
-	private static final String ONTO = "onto";
+	private static final String ONTO = "onto"; //$NON-NLS-1$
 
-	private static final String ONTO_NAME = "onto-name";
+	private static final String ONTO_NAME = "onto-name"; //$NON-NLS-1$
 
-	private static final String PATCH = "patch";
+	private static final String PATCH = "patch"; //$NON-NLS-1$
 
-	private static final String REBASE_HEAD = "head";
+	private static final String REBASE_HEAD = "head"; //$NON-NLS-1$
+
+	private static final String AMEND = "amend"; //$NON-NLS-1$
 
 	/**
 	 * The available operations
@@ -177,6 +179,8 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 
 	private final File rebaseDir;
 
+	private InteractiveHandler interactiveHandler;
+
 	/**
 	 * @param repo
 	 */
@@ -238,7 +242,12 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 			if (operation == Operation.CONTINUE) {
 				newHead = continueRebase();
 
-				if (newHead == null) {
+				File amendFile = new File(rebaseDir, AMEND);
+				boolean amendExists = amendFile.exists();
+				if (amendExists) {
+					FileUtils.delete(amendFile);
+				}
+				if (newHead == null && !amendExists) {
 					// continueRebase() returns null only if no commit was
 					// neccessary. This means that no changes where left over
 					// after resolving all conflicts. In this case, cgit stops
@@ -254,6 +263,30 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 			ObjectReader or = repo.newObjectReader();
 
 			List<Step> steps = loadSteps();
+			if (isInteractive()) {
+				interactiveHandler.prepareSteps(steps);
+				BufferedWriter fw = new BufferedWriter(
+						new OutputStreamWriter(new FileOutputStream(new File(
+								rebaseDir, GIT_REBASE_TODO)),
+								Constants.CHARACTER_ENCODING));
+				fw.newLine();
+				try {
+					StringBuilder sb = new StringBuilder();
+					for (Step step : steps) {
+						sb.setLength(0);
+						sb.append(step.action.token);
+						sb.append(" "); //$NON-NLS-1$
+						sb.append(step.commit.name());
+						sb.append(" "); //$NON-NLS-1$
+						sb.append(RawParseUtils.decode(step.shortMessage)
+								.trim());
+						fw.write(sb.toString());
+						fw.newLine();
+					}
+				} finally {
+					fw.close();
+				}
+			}
 			for (Step step : steps) {
 				popSteps(1);
 				Collection<ObjectId> ids = or.resolve(step.commit);
@@ -295,6 +328,20 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 							newHead = cherryPickResult.getNewHead();
 						}
 					}
+					switch (step.action) {
+					case PICK:
+						continue; // continue rebase process on pick command
+					case REWORD:
+						String oldMessage = commitToPick.getFullMessage();
+						String newMessage = interactiveHandler
+								.modifyCommitMessage(oldMessage);
+						newHead = new Git(repo).commit().setMessage(newMessage)
+								.setAmend(true).call();
+						continue;
+					case EDIT:
+						createFile(rebaseDir, AMEND, commitToPick.name());
+						return stop(commitToPick);
+					}
 				} finally {
 					monitor.endTask();
 				}
@@ -308,6 +355,8 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 				return RebaseResult.OK_RESULT;
 			}
 			return RebaseResult.FAST_FORWARD_RESULT;
+		} catch (CheckoutConflictException cce) {
+			return new RebaseResult(cce.getConflictingPaths());
 		} catch (IOException ioe) {
 			throw new JGitInternalException(ioe.getMessage(), ioe);
 		}
@@ -351,7 +400,7 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 	}
 
 	private RevCommit checkoutCurrentHead() throws IOException, NoHeadException {
-		ObjectId headTree = repo.resolve(Constants.HEAD + "^{tree}");
+		ObjectId headTree = repo.resolve(Constants.HEAD + "^{tree}"); //$NON-NLS-1$
 		if (headTree == null)
 			throw new NoHeadException(
 					JGitText.get().cannotRebaseWithoutCurrentHead);
@@ -395,7 +444,7 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 		treeWalk.reset();
 		treeWalk.setRecursive(true);
 		treeWalk.addTree(new DirCacheIterator(dc));
-		ObjectId id = repo.resolve(Constants.HEAD + "^{tree}");
+		ObjectId id = repo.resolve(Constants.HEAD + "^{tree}"); //$NON-NLS-1$
 		if (id == null)
 			throw new NoHeadException(
 					JGitText.get().cannotRebaseWithoutCurrentHead);
@@ -449,23 +498,23 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 	String toAuthorScript(PersonIdent author) {
 		StringBuilder sb = new StringBuilder(100);
 		sb.append(GIT_AUTHOR_NAME);
-		sb.append("='");
+		sb.append("='"); //$NON-NLS-1$
 		sb.append(author.getName());
-		sb.append("'\n");
+		sb.append("'\n"); //$NON-NLS-1$
 		sb.append(GIT_AUTHOR_EMAIL);
-		sb.append("='");
+		sb.append("='"); //$NON-NLS-1$
 		sb.append(author.getEmailAddress());
-		sb.append("'\n");
+		sb.append("'\n"); //$NON-NLS-1$
 		// the command line uses the "external String"
 		// representation for date and timezone
 		sb.append(GIT_AUTHOR_DATE);
-		sb.append("='");
-		sb.append("@"); // @ for time in seconds since 1970
+		sb.append("='"); //$NON-NLS-1$
+		sb.append("@"); // @ for time in seconds since 1970 //$NON-NLS-1$
 		String externalString = author.toExternalString();
 		sb
 				.append(externalString.substring(externalString
 						.lastIndexOf('>') + 2));
-		sb.append("'\n");
+		sb.append("'\n"); //$NON-NLS-1$
 		return sb.toString();
 	}
 
@@ -492,6 +541,8 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 				String popCandidate = br.readLine();
 				if (popCandidate == null)
 					break;
+				if (popCandidate.length() == 0)
+					continue;
 				if (popCandidate.charAt(0) == '#')
 					continue;
 				int spaceIndex = popCandidate.indexOf(' ');
@@ -564,9 +615,9 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 		RevCommit headCommit = walk.lookupCommit(headId);
 		RevCommit upstream = walk.lookupCommit(upstreamCommit.getId());
 
-		if (walk.isMergedInto(upstream, headCommit))
+		if (!isInteractive() && walk.isMergedInto(upstream, headCommit))
 			return RebaseResult.UP_TO_DATE_RESULT;
-		else if (walk.isMergedInto(headCommit, upstream)) {
+		else if (!isInteractive() && walk.isMergedInto(headCommit, upstream)) {
 			// head is already merged into upstream, fast-foward
 			monitor.beginTask(MessageFormat.format(
 					JGitText.get().resettingHead,
@@ -606,7 +657,7 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 		createFile(rebaseDir, HEAD_NAME, headName);
 		createFile(rebaseDir, ONTO, upstreamCommit.name());
 		createFile(rebaseDir, ONTO_NAME, upstreamCommitName);
-		createFile(rebaseDir, INTERACTIVE, "");
+		createFile(rebaseDir, INTERACTIVE, ""); //$NON-NLS-1$
 		BufferedWriter fw = new BufferedWriter(new OutputStreamWriter(
 				new FileOutputStream(new File(rebaseDir, GIT_REBASE_TODO)),
 				Constants.CHARACTER_ENCODING));
@@ -619,9 +670,9 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 			for (RevCommit commit : cherryPickList) {
 				sb.setLength(0);
 				sb.append(Action.PICK.toToken());
-				sb.append(" ");
+				sb.append(" "); //$NON-NLS-1$
 				sb.append(reader.abbreviate(commit).name());
-				sb.append(" ");
+				sb.append(" "); //$NON-NLS-1$
 				sb.append(commit.getShortMessage());
 				fw.write(sb.toString());
 				fw.newLine();
@@ -647,6 +698,10 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 		return null;
 	}
 
+	private boolean isInteractive() {
+		return interactiveHandler != null;
+	}
+
 	/**
 	 * checks if we can fast-forward and returns the new head if it is possible
 	 *
@@ -694,8 +749,8 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 				RefUpdate rup = repo.updateRef(headName);
 				rup.setExpectedOldObjectId(oldCommit);
 				rup.setNewObjectId(newCommit);
-				rup.setRefLogMessage("Fast-foward from " + oldCommit.name()
-						+ " to " + newCommit.name(), false);
+				rup.setRefLogMessage("Fast-foward from " + oldCommit.name() //$NON-NLS-1$
+						+ " to " + newCommit.name(), false); //$NON-NLS-1$
 				Result res = rup.update(walk);
 				switch (res) {
 				case FAST_FORWARD:
@@ -703,7 +758,7 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 				case FORCED:
 					break;
 				default:
-					throw new IOException("Could not fast-forward");
+					throw new IOException("Could not fast-forward"); //$NON-NLS-1$
 				}
 			}
 			return newCommit;
@@ -769,7 +824,11 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 					ProgressMonitor.UNKNOWN);
 
 			DirCacheCheckout dco;
-			RevCommit commit = walk.parseCommit(repo.resolve(commitId));
+			if (commitId == null)
+				throw new JGitInternalException(
+						JGitText.get().abortingRebaseFailedNoOrigHead);
+			ObjectId id = repo.resolve(commitId);
+			RevCommit commit = walk.parseCommit(id);
 			if (result.getStatus().equals(Status.FAILED)) {
 				RevCommit head = walk.parseCommit(repo.resolve(Constants.HEAD));
 				dco = new DirCacheCheckout(repo, head.getTree(),
@@ -823,13 +882,18 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 		return RawParseUtils.decode(content, 0, end);
 	}
 
-	private boolean checkoutCommit(RevCommit commit) throws IOException {
+	private boolean checkoutCommit(RevCommit commit) throws IOException,
+			CheckoutConflictException {
 		try {
 			RevCommit head = walk.parseCommit(repo.resolve(Constants.HEAD));
 			DirCacheCheckout dco = new DirCacheCheckout(repo, head.getTree(),
 					repo.lockDirCache(), commit.getTree());
 			dco.setFailOnConflict(true);
-			dco.checkout();
+			try {
+				dco.checkout();
+			} catch (org.eclipse.jgit.errors.CheckoutConflictException cce) {
+				throw new CheckoutConflictException(dco.getConflicts(), cce);
+			}
 			// update the HEAD
 			RefUpdate refUpdate = repo.updateRef(Constants.HEAD, true);
 			refUpdate.setExpectedOldObjectId(head);
@@ -988,34 +1052,87 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 		return this;
 	}
 
-	static enum Action {
-		PICK("pick"); // later add SQUASH, EDIT, etc.
+	/**
+	 * Enables interactive rebase
+	 *
+	 * @param handler
+	 * @return this
+	 */
+	public RebaseCommand runInteractively(InteractiveHandler handler) {
+		this.interactiveHandler = handler;
+		return this;
+	}
+
+	/**
+	 * Allows configure rebase interactive process and modify commit message
+	 */
+	public interface InteractiveHandler {
+		/**
+		 * Given list of {@code steps} should be modified according to user
+		 * rebase configuration
+		 * @param steps
+		 *            initial configuration of rebase interactive
+		 */
+		void prepareSteps(List<Step> steps);
+
+		/**
+		 * Used for editing commit message on REWORD
+		 *
+		 * @param commit
+		 * @return new commit message
+		 */
+		String modifyCommitMessage(String commit);
+	}
+
+	/**
+	 * Describes rebase actions
+	 */
+	public static enum Action {
+		/** Use commit */
+		PICK("pick", "p"), //$NON-NLS-1$ //$NON-NLS-2$
+		/** Use commit, but edit the commit message */
+		REWORD("reword", "r"), //$NON-NLS-1$ //$NON-NLS-2$
+		/** Use commit, but stop for amending */
+		EDIT("edit", "e"); // later add SQUASH, FIXUP, etc. //$NON-NLS-1$ //$NON-NLS-2$
 
 		private final String token;
 
-		private Action(String token) {
+		private final String shortToken;
+
+		private Action(String token, String shortToken) {
 			this.token = token;
+			this.shortToken = shortToken;
 		}
 
+		/**
+		 * @return full action token name
+		 */
 		public String toToken() {
 			return this.token;
 		}
 
+		@SuppressWarnings("nls")
 		@Override
 		public String toString() {
 			return "Action[" + token + "]";
 		}
 
 		static Action parse(String token) {
-			if (token.equals("pick") || token.equals("p"))
-				return PICK;
+			for (Action action : Action.values()) {
+				if (action.token.equals(token)
+						|| action.shortToken.equals(token))
+					return action;
+			}
 			throw new JGitInternalException(MessageFormat.format(
 					JGitText.get().unknownOrUnsupportedCommand, token,
-					PICK.toToken()));
+					Action.values()));
 		}
 	}
 
-	static class Step {
+	/**
+	 * Describes single rebase step
+	 */
+	public static class Step {
 		Action action;
 
 		AbbreviatedObjectId commit;
@@ -1026,9 +1143,42 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 			this.action = action;
 		}
 
+		/**
+		 * @return rebase action type
+		 */
+		public Action getAction() {
+			return action;
+		}
+
+		/**
+		 * @param action
+		 */
+		public void setAction(Action action) {
+			this.action = action;
+		}
+
+		/**
+		 * @return abbreviated commit SHA-1 of commit that action will be
+		 *         performed on
+		 */
+		public AbbreviatedObjectId getCommit() {
+			return commit;
+		}
+
+		/**
+		 * @return short message commit of commit that action will be performed
+		 *         on
+		 */
+		public byte[] getShortMessage() {
+			return shortMessage;
+		}
+
+		@SuppressWarnings("nls")
 		@Override
 		public String toString() {
-			return "Step[" + action + ", "
+			return "Step["
+					+ action
+					+ ", "
 					+ ((commit == null) ? "null" : commit)
 					+ ", "
 					+ ((shortMessage == null) ? "null" : new String(
@@ -1060,7 +1210,7 @@ public class RebaseCommand extends GitCommand<RebaseResult> {
 
 		// the time is saved as <seconds since 1970> <timezone offset>
 		int timeStart = 0;
-		if (time.startsWith("@"))
+		if (time.startsWith("@")) //$NON-NLS-1$
 			timeStart = 1;
 		else
 			timeStart = 0;
