@@ -66,6 +66,7 @@ import org.eclipse.jgit.lib.ObjectIdRef;
 import org.eclipse.jgit.lib.Ref;
 import org.eclipse.jgit.lib.Ref.Storage;
 import org.eclipse.jgit.lib.Repository;
+import org.eclipse.jgit.merge.MergeMessageFormatter;
 import org.eclipse.jgit.merge.MergeStrategy;
 import org.eclipse.jgit.merge.ResolveMerger;
 import org.eclipse.jgit.merge.ResolveMerger.MergeFailureReason;
@@ -86,6 +87,8 @@ import org.eclipse.jgit.treewalk.FileTreeIterator;
 public class RevertCommand extends GitCommand<RevCommit> {
 	private List<Ref> commits = new LinkedList<Ref>();
 
+	private String ourCommitName = null;
+
 	private List<Ref> revertedRefs = new LinkedList<Ref>();
 
 	private MergeResult failingResult;
@@ -143,18 +146,31 @@ public class RevertCommand extends GitCommand<RevCommit> {
 				RevCommit srcCommit = revWalk.parseCommit(srcObjectId);
 
 				// get the parent of the commit to revert
-				if (srcCommit.getParentCount() != 1) {
+				if (srcCommit.getParentCount() != 1)
 					throw new MultipleParentsNotAllowedException(
-							JGitText.get().canOnlyRevertCommitsWithOneParent);
-				}
+							MessageFormat.format(
+									JGitText.get().canOnlyRevertCommitsWithOneParent,
+									srcCommit.name(),
+									Integer.valueOf(srcCommit.getParentCount())));
+
 				RevCommit srcParent = srcCommit.getParent(0);
 				revWalk.parseHeaders(srcParent);
 
+				String ourName = calculateOurName(headRef);
+				String revertName = srcCommit.getId().abbreviate(7).name()
+						+ " " + srcCommit.getShortMessage(); //$NON-NLS-1$
+
 				ResolveMerger merger = (ResolveMerger) MergeStrategy.RESOLVE
 						.newMerger(repo);
 				merger.setWorkingTreeIterator(new FileTreeIterator(repo));
 				merger.setBase(srcCommit.getTree());
+				merger.setCommitNames(new String[] { "BASE", ourName, revertName }); //$NON-NLS-1$ //$NON-NLS-2$
 
+				String shortMessage = "Revert \"" + srcCommit.getShortMessage() //$NON-NLS-1$
+						+ "\""; //$NON-NLS-1$
+				String newMessage = shortMessage + "\n\n"
+						+ "This reverts commit " + srcCommit.getId().getName() //$NON-NLS-1$
+						+ ".\n"; //$NON-NLS-1$
 				if (merger.merge(headCommit, srcParent)) {
 					if (AnyObjectId.equals(headCommit.getTree().getId(), merger
 							.getResultTreeId()))
@@ -164,13 +180,9 @@ public class RevertCommand extends GitCommand<RevCommit> {
 							merger.getResultTreeId());
 					dco.setFailOnConflict(true);
 					dco.checkout();
-					String shortMessage = "Revert \"" + srcCommit.getShortMessage() + "\"";
-					String newMessage = shortMessage + "\n\n"
-							+ "This reverts commit "
-							+ srcCommit.getId().getName() + ".\n";
 					newHead = new Git(getRepository()).commit()
 							.setMessage(newMessage)
-							.setReflogComment("revert: " + shortMessage).call();
+							.setReflogComment("revert: " + shortMessage).call(); //$NON-NLS-1$
 					revertedRefs.add(src);
 				} else {
 					unmergedPaths = merger.getUnmergedPaths();
@@ -183,6 +195,20 @@ public class RevertCommand extends GitCommand<RevCommit> {
 										srcParent.getId() },
 								MergeStatus.FAILED, MergeStrategy.RESOLVE,
 								merger.getMergeResults(), failingPaths, null);
+					else
+						failingResult = new MergeResult(null,
+								merger.getBaseCommit(0, 1),
+								new ObjectId[] { headCommit.getId(),
+										srcParent.getId() },
+								MergeStatus.CONFLICTING, MergeStrategy.RESOLVE,
+								merger.getMergeResults(), failingPaths, null);
+					if (!merger.failed() && !unmergedPaths.isEmpty()) {
+						String message = new MergeMessageFormatter()
+						.formatWithConflicts(newMessage,
+								merger.getUnmergedPaths());
+						repo.writeRevertHead(srcCommit.getId());
+						repo.writeMergeCommitMsg(message);
+					}
 					return null;
 				}
 			}
@@ -230,6 +256,26 @@ public class RevertCommand extends GitCommand<RevCommit> {
 				commit.copy()));
 	}
 
+	/**
+	 * @param ourCommitName
+	 *            the name that should be used in the "OURS" place for conflict
+	 *            markers
+	 * @return {@code this}
+	 */
+	public RevertCommand setOurCommitName(String ourCommitName) {
+		this.ourCommitName = ourCommitName;
+		return this;
+	}
+
+	private String calculateOurName(Ref headRef) {
+		if (ourCommitName != null)
+			return ourCommitName;
+
+		String targetRefName = headRef.getTarget().getName();
+		String headName = Repository.shortenRefName(targetRefName);
+		return headName;
+	}
+
 	/**
 	 * @return the list of successfully reverted {@link Ref}'s. Never
 	 *         <code>null</code> but maybe an empty list if no commit was
