@@ -137,6 +137,13 @@ public class Status {
 		return Collections.unmodifiableSet(diff.getUntracked());
 	}
 
+	/**
+	 * @return set of directories that are not ignored, and not in the index.
+	 */
+	public Set<String> getUntrackedFolders() {
+		return Collections.unmodifiableSet(diff.getUntrackedFolders());
+	}
+
 	/**
 	 * @return list of files that are in conflict. (e.g what you get if you
 	 *         modify file that was modified by someone else in the meantime)
@@ -144,4 +151,11 @@ public class Status {
 	public Set<String> getConflicting() {
 		return Collections.unmodifiableSet(diff.getConflicting());
 	}
+
+	/**
+	 * @return set of files and folders that are ignored and not in the index.
+	 */
+	public Set<String> getIgnoredNotInIndex() {
+		return Collections.unmodifiableSet(diff.getIgnoredNotInIndex());
+	}
 }
