@@ -3,6 +3,7 @@
  * Copyright (C) 2008-2010, Google Inc.
  * Copyright (C) 2006-2010, Robin Rosenberg <robin.rosenberg@dewire.com>
  * Copyright (C) 2006-2012, Shawn O. Pearce <spearce@spearce.org>
+ * Copyright (C) 2012, Daniel Megert <daniel_megert@ch.ibm.com>
  * and other copyright owners as documented in the project's IP log.
  *
  * This program and the accompanying materials are made available
@@ -377,7 +378,8 @@ public abstract class Repository {
 	 *             on serious errors
 	 */
 	public ObjectId resolve(final String revstr)
-			throws AmbiguousObjectException, IOException {
+			throws AmbiguousObjectException, IncorrectObjectTypeException,
+			RevisionSyntaxException, IOException {
 		RevWalk rw = new RevWalk(this);
 		try {
 			Object resolved = resolve(rw, revstr);
@@ -429,7 +431,12 @@ public abstract class Repository {
 			case '^':
 				if (rev == null) {
 					if (name == null)
-						name = new String(revChars, done, i);
+						if (done == 0)
+							name = new String(revChars, done, i);
+						else {
+							done = i + 1;
+							break;
+						}
 					rev = parseSimple(rw, name);
 					name = null;
 					if (rev == null)
@@ -471,7 +478,7 @@ public abstract class Repository {
 								rev = commit.getParent(pnum - 1);
 						}
 						i = j - 1;
-						done = i;
+						done = j;
 						break;
 					case '{':
 						int k;
@@ -484,16 +491,16 @@ public abstract class Repository {
 						}
 						i = k;
 						if (item != null)
-							if (item.equals("tree")) {
+							if (item.equals("tree")) { //$NON-NLS-1$
 								rev = rw.parseTree(rev);
-							} else if (item.equals("commit")) {
+							} else if (item.equals("commit")) { //$NON-NLS-1$
 								rev = rw.parseCommit(rev);
-							} else if (item.equals("blob")) {
+							} else if (item.equals("blob")) { //$NON-NLS-1$
 								rev = rw.peel(rev);
 								if (!(rev instanceof RevBlob))
 									throw new IncorrectObjectTypeException(rev,
 											Constants.TYPE_BLOB);
-							} else if (item.equals("")) {
+							} else if (item.equals("")) { //$NON-NLS-1$
 								rev = rw.peel(rev);
 							} else
 								throw new RevisionSyntaxException(revstr);
@@ -502,7 +509,7 @@ public abstract class Repository {
 						done = k;
 						break;
 					default:
-						rev = rw.parseAny(rev);
+						rev = rw.peel(rev);
 						if (rev instanceof RevCommit) {
 							RevCommit commit = ((RevCommit) rev);
 							if (commit.getParentCount() == 0)
@@ -512,7 +519,6 @@ public abstract class Repository {
 						} else
 							throw new IncorrectObjectTypeException(rev,
 									Constants.TYPE_COMMIT);
-
 					}
 				} else {
 					rev = rw.peel(rev);
@@ -526,12 +532,19 @@ public abstract class Repository {
 						throw new IncorrectObjectTypeException(rev,
 								Constants.TYPE_COMMIT);
 				}
+				done = i + 1;
 				break;
 			case '~':
 				if (rev == null) {
 					if (name == null)
-						name = new String(revChars, done, i);
+						if (done == 0)
+							name = new String(revChars, done, i);
+						else {
+							done = i + 1;
+							break;
+						}
 					rev = parseSimple(rw, name);
+					name = null;
 					if (rev == null)
 						return null;
 				}
@@ -567,10 +580,13 @@ public abstract class Repository {
 					--dist;
 				}
 				i = l - 1;
+				done = l;
 				break;
 			case '@':
 				if (rev != null)
 					throw new RevisionSyntaxException(revstr);
+				if (i + 1 < revChars.length && revChars[i + 1] != '{')
+					continue;
 				int m;
 				String time = null;
 				for (m = i + 2; m < revChars.length; ++m) {
@@ -580,14 +596,17 @@ public abstract class Repository {
 					}
 				}
 				if (time != null) {
-					if (time.equals("upstream")) {
+					if (time.equals("upstream")) { //$NON-NLS-1$
 						if (name == null)
 							name = new String(revChars, done, i);
-						if (name.equals(""))
+						if (name.equals("")) //$NON-NLS-1$
 							// Currently checked out branch, HEAD if
 							// detached
 							name = Constants.HEAD;
+						if (!Repository.isValidRefName("x/" + name)) //$NON-NLS-1$
+							throw new RevisionSyntaxException(revstr);
 						Ref ref = getRef(name);
+						name = null;
 						if (ref == null)
 							return null;
 						if (ref.isSymbolic())
@@ -597,7 +616,7 @@ public abstract class Repository {
 						RemoteConfig remoteConfig;
 						try {
 							remoteConfig = new RemoteConfig(getConfig(),
-									"origin");
+									"origin"); //$NON-NLS-1$
 						} catch (URISyntaxException e) {
 							throw new RevisionSyntaxException(revstr);
 						}
@@ -618,7 +637,7 @@ public abstract class Repository {
 						}
 						if (name == null)
 							throw new RevisionSyntaxException(revstr);
-					} else if (time.matches("^-\\d+$")) {
+					} else if (time.matches("^-\\d+$")) { //$NON-NLS-1$
 						if (name != null)
 							throw new RevisionSyntaxException(revstr);
 						else {
@@ -632,9 +651,12 @@ public abstract class Repository {
 					} else {
 						if (name == null)
 							name = new String(revChars, done, i);
-						if (name.equals(""))
+						if (name.equals("")) //$NON-NLS-1$
 							name = Constants.HEAD;
+						if (!Repository.isValidRefName("x/" + name)) //$NON-NLS-1$
+							throw new RevisionSyntaxException(revstr);
 						Ref ref = getRef(name);
+						name = null;
 						if (ref == null)
 							return null;
 						// @{n} means current branch, not HEAD@{1} unless
@@ -642,7 +664,6 @@ public abstract class Repository {
 						if (ref.isSymbolic())
 							ref = ref.getLeaf();
 						rev = resolveReflog(rw, ref, time);
-						name = null;
 					}
 					i = m;
 				} else
@@ -653,9 +674,10 @@ public abstract class Repository {
 				if (rev == null) {
 					if (name == null)
 						name = new String(revChars, done, i);
-					if (name.equals(""))
+					if (name.equals("")) //$NON-NLS-1$
 						name = Constants.HEAD;
 					rev = parseSimple(rw, name);
+					name = null;
 				}
 				if (rev == null)
 					return null;
@@ -677,7 +699,11 @@ public abstract class Repository {
 			return rev.copy();
 		if (name != null)
 			return name;
+		if (done == revstr.length())
+			return null;
 		name = revstr.substring(done);
+		if (!Repository.isValidRefName("x/" + name)) //$NON-NLS-1$
+			throw new RevisionSyntaxException(revstr);
 		if (getRef(name) != null)
 			return name;
 		return resolveSimple(name);
@@ -706,14 +732,16 @@ public abstract class Repository {
 		if (ObjectId.isId(revstr))
 			return ObjectId.fromString(revstr);
 
-		Ref r = getRefDatabase().getRef(revstr);
-		if (r != null)
-			return r.getObjectId();
+		if (Repository.isValidRefName("x/" + revstr)) { //$NON-NLS-1$
+			Ref r = getRefDatabase().getRef(revstr);
+			if (r != null)
+				return r.getObjectId();
+		}
 
 		if (AbbreviatedObjectId.isId(revstr))
 			return resolveAbbreviation(revstr);
 
-		int dashg = revstr.indexOf("-g");
+		int dashg = revstr.indexOf("-g"); //$NON-NLS-1$
 		if ((dashg + 5) < revstr.length() && 0 <= dashg
 				&& isHex(revstr.charAt(dashg + 2))
 				&& isHex(revstr.charAt(dashg + 3))
@@ -799,14 +827,15 @@ public abstract class Repository {
 		getRefDatabase().close();
 	}
 
+	@SuppressWarnings("nls")
 	public String toString() {
 		String desc;
 		if (getDirectory() != null)
 			desc = getDirectory().getPath();
 		else
-			desc = getClass().getSimpleName() + "-"
+			desc = getClass().getSimpleName() + "-" //$NON-NLS-1$
 					+ System.identityHashCode(this);
-		return "Repository[" + desc + "]";
+		return "Repository[" + desc + "]"; //$NON-NLS-1$
 	}
 
 	/**
@@ -1040,22 +1069,22 @@ public abstract class Repository {
 			return RepositoryState.BARE;
 
 		// Pre Git-1.6 logic
-		if (new File(getWorkTree(), ".dotest").exists())
+		if (new File(getWorkTree(), ".dotest").exists()) //$NON-NLS-1$
 			return RepositoryState.REBASING;
-		if (new File(getDirectory(), ".dotest-merge").exists())
+		if (new File(getDirectory(), ".dotest-merge").exists()) //$NON-NLS-1$
 			return RepositoryState.REBASING_INTERACTIVE;
 
 		// From 1.6 onwards
-		if (new File(getDirectory(),"rebase-apply/rebasing").exists())
+		if (new File(getDirectory(),"rebase-apply/rebasing").exists()) //$NON-NLS-1$
 			return RepositoryState.REBASING_REBASING;
-		if (new File(getDirectory(),"rebase-apply/applying").exists())
+		if (new File(getDirectory(),"rebase-apply/applying").exists()) //$NON-NLS-1$
 			return RepositoryState.APPLY;
-		if (new File(getDirectory(),"rebase-apply").exists())
+		if (new File(getDirectory(),"rebase-apply").exists()) //$NON-NLS-1$
 			return RepositoryState.REBASING;
 
-		if (new File(getDirectory(),"rebase-merge/interactive").exists())
+		if (new File(getDirectory(),"rebase-merge/interactive").exists()) //$NON-NLS-1$
 			return RepositoryState.REBASING_INTERACTIVE;
-		if (new File(getDirectory(),"rebase-merge").exists())
+		if (new File(getDirectory(),"rebase-merge").exists()) //$NON-NLS-1$
 			return RepositoryState.REBASING_MERGE;
 
 		// Both versions
@@ -1074,7 +1103,7 @@ public abstract class Repository {
 			return RepositoryState.MERGING;
 		}
 
-		if (new File(getDirectory(), "BISECT_LOG").exists())
+		if (new File(getDirectory(), "BISECT_LOG").exists()) //$NON-NLS-1$
 			return RepositoryState.BISECTING;
 
 		if (new File(getDirectory(), Constants.CHERRY_PICK_HEAD).exists()) {
@@ -1090,6 +1119,19 @@ public abstract class Repository {
 			return RepositoryState.CHERRY_PICKING;
 		}
 
+		if (new File(getDirectory(), Constants.REVERT_HEAD).exists()) {
+			try {
+				if (!readDirCache().hasUnmergedPaths()) {
+					// no unmerged paths
+					return RepositoryState.REVERTING_RESOLVED;
+				}
+			} catch (IOException e) {
+				// fall through to REVERTING
+			}
+
+			return RepositoryState.REVERTING;
+		}
+
 		return RepositoryState.SAFE;
 	}
 
@@ -1108,7 +1150,7 @@ public abstract class Repository {
 		final int len = refName.length();
 		if (len == 0)
 			return false;
-		if (refName.endsWith(".lock"))
+		if (refName.endsWith(".lock")) //$NON-NLS-1$
 			return false;
 
 		int components = 1;
@@ -1129,6 +1171,8 @@ public abstract class Repository {
 			case '/':
 				if (i == 0 || i == len - 1)
 					return false;
+				if (p == '/')
+					return false;
 				components++;
 				break;
 			case '{':
@@ -1138,6 +1182,7 @@ public abstract class Repository {
 			case '~': case '^': case ':':
 			case '?': case '[': case '*':
 			case '\\':
+			case '\u007F':
 				return false;
 			}
 			p = c;
@@ -1163,7 +1208,7 @@ public abstract class Repository {
 			File absWd = workDir.isAbsolute() ? workDir : workDir.getAbsoluteFile();
 			File absFile = file.isAbsolute() ? file : file.getAbsoluteFile();
 			if (absWd == workDir && absFile == file)
-				return "";
+				return ""; //$NON-NLS-1$
 			return stripWorkDir(absWd, absFile);
 		}
 
@@ -1330,6 +1375,27 @@ public abstract class Repository {
 		return ObjectId.fromString(raw, 0);
 	}
 
+	/**
+	 * Return the information stored in the file $GIT_DIR/REVERT_HEAD.
+	 *
+	 * @return object id from REVERT_HEAD file or {@code null} if this file
+	 *         doesn't exist. Also if the file exists but is empty {@code null}
+	 *         will be returned
+	 * @throws IOException
+	 * @throws NoWorkTreeException
+	 *             if this is bare, which implies it has no working directory.
+	 *             See {@link #isBare()}.
+	 */
+	public ObjectId readRevertHead() throws IOException, NoWorkTreeException {
+		if (isBare() || getDirectory() == null)
+			throw new NoWorkTreeException();
+
+		byte[] raw = readGitDirectoryFile(Constants.REVERT_HEAD);
+		if (raw == null)
+			return null;
+		return ObjectId.fromString(raw, 0);
+	}
+
 	/**
 	 * Write cherry pick commit into $GIT_DIR/CHERRY_PICK_HEAD. This is used in
 	 * case of conflicts to store the cherry which was tried to be picked.
@@ -1345,6 +1411,21 @@ public abstract class Repository {
 		writeHeadsFile(heads, Constants.CHERRY_PICK_HEAD);
 	}
 
+	/**
+	 * Write revert commit into $GIT_DIR/REVERT_HEAD. This is used in case of
+	 * conflicts to store the revert which was tried to be picked.
+	 *
+	 * @param head
+	 *            an object id of the revert commit or <code>null</code> to
+	 *            delete the file
+	 * @throws IOException
+	 */
+	public void writeRevertHead(ObjectId head) throws IOException {
+		List<ObjectId> heads = (head != null) ? Collections.singletonList(head)
+				: null;
+		writeHeadsFile(heads, Constants.REVERT_HEAD);
+	}
+
 	/**
 	 * Write original HEAD commit into $GIT_DIR/ORIG_HEAD.
 	 *
@@ -1482,4 +1563,5 @@ public abstract class Repository {
 			FileUtils.delete(headsFile, FileUtils.SKIP_MISSING);
 		}
 	}
+
 }
