@@ -80,7 +80,11 @@ public class RevCommit extends RevObject {
 	 *         available to the caller.
 	 */
 	public static RevCommit parse(byte[] raw) {
-		return parse(new RevWalk((ObjectReader) null), raw);
+		try {
+			return parse(new RevWalk((ObjectReader) null), raw);
+		} catch (IOException ex) {
+			throw new RuntimeException(ex);
+		}
 	}
 
 	/**
@@ -88,7 +92,7 @@ public class RevCommit extends RevObject {
 	 *
 	 * This method inserts the commit directly into the caller supplied revision
 	 * pool, making it appear as though the commit exists in the repository,
-	 * even if it doesn't.  The repository under the pool is not affected.
+	 * even if it doesn't. The repository under the pool is not affected.
 	 *
 	 * @param rw
 	 *            the revision pool to allocate the commit within. The commit's
@@ -97,8 +101,10 @@ public class RevCommit extends RevObject {
 	 *            the canonical formatted commit to be parsed.
 	 * @return the parsed commit, in an isolated revision pool that is not
 	 *         available to the caller.
+	 * @throws IOException
+	 *             in case of RevWalk initialization fails
 	 */
-	public static RevCommit parse(RevWalk rw, byte[] raw) {
+	public static RevCommit parse(RevWalk rw, byte[] raw) throws IOException {
 		ObjectInserter.Formatter fmt = new ObjectInserter.Formatter();
 		boolean retain = rw.isRetainBody();
 		rw.setRetainBody(true);
@@ -146,7 +152,11 @@ public class RevCommit extends RevObject {
 		}
 	}
 
-	void parseCanonical(final RevWalk walk, final byte[] raw) {
+	void parseCanonical(final RevWalk walk, final byte[] raw)
+			throws IOException {
+		if (!walk.shallowCommitsInitialized)
+			walk.initializeShallowCommits();
+
 		final MutableObjectId idBuffer = walk.idBuffer;
 		idBuffer.fromString(raw, 5);
 		tree = walk.lookupTree(idBuffer);
@@ -381,7 +391,7 @@ public class RevCommit extends RevObject {
 		final byte[] raw = buffer;
 		final int msgB = RawParseUtils.commitMessage(raw, 0);
 		if (msgB < 0)
-			return "";
+			return ""; //$NON-NLS-1$
 		final Charset enc = RawParseUtils.parseEncoding(raw);
 		return RawParseUtils.decode(enc, raw, msgB, raw.length);
 	}
@@ -405,7 +415,7 @@ public class RevCommit extends RevObject {
 		final byte[] raw = buffer;
 		final int msgB = RawParseUtils.commitMessage(raw, 0);
 		if (msgB < 0)
-			return "";
+			return ""; //$NON-NLS-1$
 
 		final Charset enc = RawParseUtils.parseEncoding(raw);
 		final int msgE = RawParseUtils.endOfParagraph(raw, msgB);
