@@ -49,6 +49,7 @@
 
 package org.eclipse.jgit.storage.file;
 
+import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.FileNotFoundException;
 import java.io.IOException;
@@ -70,8 +71,13 @@ import org.eclipse.jgit.util.RawParseUtils;
  */
 public class FileBasedConfig extends StoredConfig {
 	private final File configFile;
+
 	private final FS fs;
+
+	private boolean utf8Bom;
+
 	private volatile FileSnapshot snapshot;
+
 	private volatile ObjectId hash;
 
 	/**
@@ -141,7 +147,16 @@ public class FileBasedConfig extends StoredConfig {
 				else
 					snapshot = newSnapshot;
 			} else {
-				fromText(RawParseUtils.decode(in));
+				final String decoded;
+				if (in.length >= 3 && in[0] == (byte) 0xEF
+						&& in[1] == (byte) 0xBB && in[2] == (byte) 0xBF) {
+					decoded = RawParseUtils.decode(RawParseUtils.UTF8_CHARSET,
+							in, 3, in.length);
+					utf8Bom = true;
+				} else {
+					decoded = RawParseUtils.decode(in);
+				}
+				fromText(decoded);
 				snapshot = newSnapshot;
 				hash = newHash;
 			}
@@ -170,7 +185,19 @@ public class FileBasedConfig extends StoredConfig {
 	 *             the file could not be written.
 	 */
 	public void save() throws IOException {
-		final byte[] out = Constants.encode(toText());
+		final byte[] out;
+		final String text = toText();
+		if (utf8Bom) {
+			final ByteArrayOutputStream bos = new ByteArrayOutputStream();
+			bos.write(0xEF);
+			bos.write(0xBB);
+			bos.write(0xBF);
+			bos.write(text.getBytes(RawParseUtils.UTF8_CHARSET.name()));
+			out = bos.toByteArray();
+		} else {
+			out = Constants.encode(text);
+		}
+
 		final LockFile lf = new LockFile(getFile(), fs);
 		if (!lf.lock())
 			throw new LockFailedException(getFile());
@@ -198,6 +225,7 @@ public class FileBasedConfig extends StoredConfig {
 		return ObjectId.fromRaw(Constants.newMessageDigest().digest(rawText));
 	}
 
+	@SuppressWarnings("nls")
 	@Override
 	public String toString() {
 		return getClass().getSimpleName() + "[" + getFile().getPath() + "]";
