@@ -127,6 +127,12 @@ public class ObjectDirectory extends FileObjectDatabase {
 
 	private final UnpackedObjectCache unpackedObjectCache;
 
+	private final File shallowFile;
+
+	private FileSnapshot shallowFileSnapshot = FileSnapshot.DIRTY;
+
+	private Set<ObjectId> shallowCommitsIds;
+
 	/**
 	 * Initialize a reference to an on-disk object directory.
 	 *
@@ -139,21 +145,25 @@ public class ObjectDirectory extends FileObjectDatabase {
 	 * @param fs
 	 *            the file system abstraction which will be necessary to perform
 	 *            certain file system operations.
+	 * @param shallowFile
+	 *            file which contains IDs of shallow commits, null if shallow
+	 *            commits handling should be turned off
 	 * @throws IOException
 	 *             an alternate object cannot be opened.
 	 */
 	public ObjectDirectory(final Config cfg, final File dir,
-			File[] alternatePaths, FS fs) throws IOException {
+			File[] alternatePaths, FS fs, File shallowFile) throws IOException {
 		config = cfg;
 		objects = dir;
-		infoDirectory = new File(objects, "info");
-		packDirectory = new File(objects, "pack");
-		alternatesFile = new File(infoDirectory, "alternates");
-		cachedPacksFile = new File(infoDirectory, "cached-packs");
+		infoDirectory = new File(objects, "info"); //$NON-NLS-1$
+		packDirectory = new File(objects, "pack"); //$NON-NLS-1$
+		alternatesFile = new File(infoDirectory, "alternates"); //$NON-NLS-1$
+		cachedPacksFile = new File(infoDirectory, "cached-packs"); //$NON-NLS-1$
 		packList = new AtomicReference<PackList>(NO_PACKS);
 		cachedPacks = new AtomicReference<CachedPackList>();
 		unpackedObjectCache = new UnpackedObjectCache();
 		this.fs = fs;
+		this.shallowFile = shallowFile;
 
 		alternates = new AtomicReference<AlternateHandle[]>();
 		if (alternatePaths != null) {
@@ -317,35 +327,25 @@ public class ObjectDirectory extends FileObjectDatabase {
 	 *
 	 * @param pack
 	 *            path of the pack file to open.
-	 * @param idx
-	 *            path of the corresponding index file.
 	 * @return the pack that was opened and added to the database.
 	 * @throws IOException
 	 *             index file could not be opened, read, or is not recognized as
 	 *             a Git pack file index.
 	 */
-	public PackFile openPack(final File pack, final File idx)
+	public PackFile openPack(final File pack)
 			throws IOException {
 		final String p = pack.getName();
-		final String i = idx.getName();
-
-		if (p.length() != 50 || !p.startsWith("pack-") || !p.endsWith(".pack"))
+		if (p.length() != 50 || !p.startsWith("pack-") || !p.endsWith(".pack")) //$NON-NLS-1$
 			throw new IOException(MessageFormat.format(JGitText.get().notAValidPack, pack));
 
-		if (i.length() != 49 || !i.startsWith("pack-") || !i.endsWith(".idx"))
-			throw new IOException(MessageFormat.format(JGitText.get().notAValidPack, idx));
-
-		if (!p.substring(0, 45).equals(i.substring(0, 45)))
-			throw new IOException(MessageFormat.format(JGitText.get().packDoesNotMatchIndex, pack));
-
-		PackFile res = new PackFile(idx, pack);
+		PackFile res = new PackFile(pack);
 		insertPack(res);
 		return res;
 	}
 
 	@Override
 	public String toString() {
-		return "ObjectDirectory[" + getDirectory() + "]";
+		return "ObjectDirectory[" + getDirectory() + "]"; //$NON-NLS-1$
 	}
 
 	boolean hasObject1(final AnyObjectId objectId) {
@@ -577,7 +577,7 @@ public class ObjectDirectory extends FileObjectDatabase {
 		// directories are always lazily created. Note that we
 		// try the rename first as the directory likely does exist.
 		//
-		FileUtils.mkdir(dst.getParentFile());
+		FileUtils.mkdir(dst.getParentFile(), true);
 		if (tmp.renameTo(dst)) {
 			dst.setReadOnly();
 			unpackedObjectCache.add(id);
@@ -614,6 +614,30 @@ public class ObjectDirectory extends FileObjectDatabase {
 		return fs;
 	}
 
+	@Override
+	Set<ObjectId> getShallowCommits() throws IOException {
+		if (shallowFile == null || !shallowFile.isFile())
+			return Collections.emptySet();
+
+		if (shallowFileSnapshot == null
+				|| shallowFileSnapshot.isModified(shallowFile)) {
+			shallowCommitsIds = new HashSet<ObjectId>();
+
+			final BufferedReader reader = open(shallowFile);
+			try {
+				String line;
+				while ((line = reader.readLine()) != null)
+					shallowCommitsIds.add(ObjectId.fromString(line));
+			} finally {
+				reader.close();
+			}
+
+			shallowFileSnapshot = FileSnapshot.save(shallowFile);
+		}
+
+		return shallowCommitsIds;
+	}
+
 	private void insertPack(final PackFile pf) {
 		PackList o, n;
 		do {
@@ -693,11 +717,11 @@ public class ObjectDirectory extends FileObjectDatabase {
 		for (final String indexName : names) {
 			// Must match "pack-[0-9a-f]{40}.idx" to be an index.
 			//
-			if (indexName.length() != 49 || !indexName.endsWith(".idx"))
+			if (indexName.length() != 49 || !indexName.endsWith(".idx")) //$NON-NLS-1$
 				continue;
 
 			final String base = indexName.substring(0, indexName.length() - 4);
-			final String packName = base + ".pack";
+			final String packName = base + ".pack"; //$NON-NLS-1$
 			if (!names.contains(packName)) {
 				// Sometimes C Git's HTTP fetch transport leaves a
 				// .idx file behind and does not download the .pack.
@@ -713,8 +737,7 @@ public class ObjectDirectory extends FileObjectDatabase {
 			}
 
 			final File packFile = new File(packDirectory, packName);
-			final File idxFile = new File(packDirectory, indexName);
-			list.add(new PackFile(idxFile, packFile));
+			list.add(new PackFile(packFile));
 			foundNew = true;
 		}
 
@@ -772,7 +795,7 @@ public class ObjectDirectory extends FileObjectDatabase {
 			return Collections.emptySet();
 		final Set<String> nameSet = new HashSet<String>(nameList.length << 1);
 		for (final String name : nameList) {
-			if (name.startsWith("pack-"))
+			if (name.startsWith("pack-")) //$NON-NLS-1$
 				nameSet.add(name);
 		}
 		return nameSet;
@@ -829,7 +852,7 @@ public class ObjectDirectory extends FileObjectDatabase {
 			return new AlternateRepository(db);
 		}
 
-		ObjectDirectory db = new ObjectDirectory(config, objdir, null, fs);
+		ObjectDirectory db = new ObjectDirectory(config, objdir, null, fs, null);
 		return new AlternateHandle(db);
 	}
 
