@@ -45,6 +45,8 @@
 
 package org.eclipse.jgit.storage.file;
 
+import static org.eclipse.jgit.storage.pack.PackExt.INDEX;
+
 import java.io.EOFException;
 import java.io.File;
 import java.io.IOException;
@@ -74,6 +76,7 @@ import org.eclipse.jgit.lib.ObjectId;
 import org.eclipse.jgit.lib.ObjectLoader;
 import org.eclipse.jgit.storage.pack.BinaryDelta;
 import org.eclipse.jgit.storage.pack.ObjectToPack;
+import org.eclipse.jgit.storage.pack.PackExt;
 import org.eclipse.jgit.storage.pack.PackOutputStream;
 import org.eclipse.jgit.util.LongList;
 import org.eclipse.jgit.util.NB;
@@ -92,8 +95,6 @@ public class PackFile implements Iterable<PackIndex.MutableEntry> {
 		}
 	};
 
-	private final File idxFile;
-
 	private final File packFile;
 
 	private File keepFile;
@@ -135,13 +136,10 @@ public class PackFile implements Iterable<PackIndex.MutableEntry> {
 	/**
 	 * Construct a reader for an existing, pre-indexed packfile.
 	 *
-	 * @param idxFile
-	 *            path of the <code>.idx</code> file listing the contents.
 	 * @param packFile
 	 *            path of the <code>.pack</code> file holding the data.
 	 */
-	public PackFile(final File idxFile, final File packFile) {
-		this.idxFile = idxFile;
+	public PackFile(final File packFile) {
 		this.packFile = packFile;
 		this.packLastModified = (int) (packFile.lastModified() >> 10);
 
@@ -158,7 +156,7 @@ public class PackFile implements Iterable<PackIndex.MutableEntry> {
 				throw new PackInvalidException(packFile);
 
 			try {
-				final PackIndex idx = PackIndex.open(idxFile);
+				final PackIndex idx = PackIndex.open(extFile(INDEX));
 
 				if (packChecksum == null)
 					packChecksum = idx.packChecksum;
@@ -192,10 +190,10 @@ public class PackFile implements Iterable<PackIndex.MutableEntry> {
 		String name = packName;
 		if (name == null) {
 			name = getPackFile().getName();
-			if (name.startsWith("pack-"))
-				name = name.substring("pack-".length());
-			if (name.endsWith(".pack"))
-				name = name.substring(0, name.length() - ".pack".length());
+			if (name.startsWith("pack-")) //$NON-NLS-1$
+				name = name.substring("pack-".length()); //$NON-NLS-1$
+			if (name.endsWith(".pack")) //$NON-NLS-1$
+				name = name.substring(0, name.length() - ".pack".length()); //$NON-NLS-1$
 			packName = name;
 		}
 		return name;
@@ -226,7 +224,7 @@ public class PackFile implements Iterable<PackIndex.MutableEntry> {
 	 */
 	public boolean shouldBeKept() {
 		if (keepFile == null)
-			keepFile = new File(packFile.getPath() + ".keep");
+			keepFile = new File(packFile.getPath() + ".keep"); //$NON-NLS-1$
 		return keepFile.exists();
 	}
 
@@ -589,7 +587,7 @@ public class PackFile implements Iterable<PackIndex.MutableEntry> {
 			if (invalid)
 				throw new PackInvalidException(packFile);
 			synchronized (readLock) {
-				fd = new RandomAccessFile(packFile, "r");
+				fd = new RandomAccessFile(packFile, "r"); //$NON-NLS-1$
 				length = fd.length();
 				onOpenPack();
 			}
@@ -1080,4 +1078,11 @@ public class PackFile implements Iterable<PackIndex.MutableEntry> {
 			list.add(offset);
 		}
 	}
+
+	private File extFile(PackExt ext) {
+		String p = packFile.getName();
+		int dot = p.lastIndexOf('.');
+		String b = (dot < 0) ? p : p.substring(0, dot);
+		return new File(packFile.getParentFile(), b + '.' + ext.getExtension());
+	}
 }
