@@ -52,6 +52,7 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.List;
+import java.util.Set;
 import java.util.zip.DataFormatException;
 import java.util.zip.Inflater;
 
@@ -130,6 +131,11 @@ final class WindowCursor extends ObjectReader implements ObjectReuseAsIs {
 		return ldr;
 	}
 
+	@Override
+	public Set<ObjectId> getShallowCommits() throws IOException {
+		return db.getShallowCommits();
+	}
+
 	public long getObjectSize(AnyObjectId objectId, int typeHint)
 			throws MissingObjectException, IncorrectObjectTypeException,
 			IOException {
