@@ -124,61 +124,61 @@ public abstract class BasePackFetchConnection extends BasePackConnection
 	 * Include tags if we are also including the referenced objects.
 	 * @since 2.0
 	 */
-	public static final String OPTION_INCLUDE_TAG = "include-tag";
+	public static final String OPTION_INCLUDE_TAG = "include-tag"; //$NON-NLS-1$
 
 	/**
 	 * Mutli-ACK support for improved negotiation.
 	 * @since 2.0
 	 */
-	public static final String OPTION_MULTI_ACK = "multi_ack";
+	public static final String OPTION_MULTI_ACK = "multi_ack"; //$NON-NLS-1$
 
 	/**
 	 * Mutli-ACK detailed support for improved negotiation.
 	 * @since 2.0
 	 */
-	public static final String OPTION_MULTI_ACK_DETAILED = "multi_ack_detailed";
+	public static final String OPTION_MULTI_ACK_DETAILED = "multi_ack_detailed"; //$NON-NLS-1$
 
 	/**
 	 * The client supports packs with deltas but not their bases.
 	 * @since 2.0
 	 */
-	public static final String OPTION_THIN_PACK = "thin-pack";
+	public static final String OPTION_THIN_PACK = "thin-pack"; //$NON-NLS-1$
 
 	/**
 	 * The client supports using the side-band for progress messages.
 	 * @since 2.0
 	 */
-	public static final String OPTION_SIDE_BAND = "side-band";
+	public static final String OPTION_SIDE_BAND = "side-band"; //$NON-NLS-1$
 
 	/**
 	 * The client supports using the 64K side-band for progress messages.
 	 * @since 2.0
 	 */
-	public static final String OPTION_SIDE_BAND_64K = "side-band-64k";
+	public static final String OPTION_SIDE_BAND_64K = "side-band-64k"; //$NON-NLS-1$
 
 	/**
 	 * The client supports packs with OFS deltas.
 	 * @since 2.0
 	 */
-	public static final String OPTION_OFS_DELTA = "ofs-delta";
+	public static final String OPTION_OFS_DELTA = "ofs-delta"; //$NON-NLS-1$
 
 	/**
 	 * The client supports shallow fetches.
 	 * @since 2.0
 	 */
-	public static final String OPTION_SHALLOW = "shallow";
+	public static final String OPTION_SHALLOW = "shallow"; //$NON-NLS-1$
 
 	/**
 	 * The client does not want progress messages and will ignore them.
 	 * @since 2.0
 	 */
-	public static final String OPTION_NO_PROGRESS = "no-progress";
+	public static final String OPTION_NO_PROGRESS = "no-progress"; //$NON-NLS-1$
 
 	/**
 	 * The client supports receiving a pack before it has sent "done".
 	 * @since 2.0
 	 */
-	public static final String OPTION_NO_DONE = "no-done";
+	public static final String OPTION_NO_DONE = "no-done"; //$NON-NLS-1$
 
 	static enum MultiAck {
 		OFF, CONTINUE, DETAILED;
@@ -238,10 +238,10 @@ public abstract class BasePackFetchConnection extends BasePackConnection
 
 		walk = new RevWalk(local);
 		reachableCommits = new RevCommitList<RevCommit>();
-		REACHABLE = walk.newFlag("REACHABLE");
-		COMMON = walk.newFlag("COMMON");
-		STATE = walk.newFlag("STATE");
-		ADVERTISED = walk.newFlag("ADVERTISED");
+		REACHABLE = walk.newFlag("REACHABLE"); //$NON-NLS-1$
+		COMMON = walk.newFlag("COMMON"); //$NON-NLS-1$
+		STATE = walk.newFlag("STATE"); //$NON-NLS-1$
+		ADVERTISED = walk.newFlag("ADVERTISED"); //$NON-NLS-1$
 
 		walk.carry(COMMON);
 		walk.carry(REACHABLE);
@@ -258,7 +258,7 @@ public abstract class BasePackFetchConnection extends BasePackConnection
 		final boolean allowOfsDelta;
 
 		FetchConfig(final Config c) {
-			allowOfsDelta = c.getBoolean("repack", "usedeltabaseoffset", true);
+			allowOfsDelta = c.getBoolean("repack", "usedeltabaseoffset", true); //$NON-NLS-1$ //$NON-NLS-2$
 		}
 	}
 
@@ -429,7 +429,7 @@ public abstract class BasePackFetchConnection extends BasePackConnection
 			}
 
 			final StringBuilder line = new StringBuilder(46);
-			line.append("want ");
+			line.append("want "); //$NON-NLS-1$
 			line.append(r.getObjectId().name());
 			if (first) {
 				line.append(enableCapabilities());
@@ -500,7 +500,7 @@ public abstract class BasePackFetchConnection extends BasePackConnection
 			if (c == null)
 				break SEND_HAVES;
 
-			pckOut.writeString("have " + c.getId().name() + "\n");
+			pckOut.writeString("have " + c.getId().name() + "\n"); //$NON-NLS-1$ //$NON-NLS-2$
 			havesSent++;
 			havesSinceLastContinue++;
 
@@ -595,7 +595,7 @@ public abstract class BasePackFetchConnection extends BasePackConnection
 			// loop above while in the middle of a request. This allows us
 			// to just write done immediately.
 			//
-			pckOut.writeString("done\n");
+			pckOut.writeString("done\n"); //$NON-NLS-1$
 			pckOut.flush();
 		}
 
