@@ -149,7 +149,7 @@ class WalkPushConnection extends BaseConnection implements PushConnection {
 		final List<RemoteRefUpdate> updates = new ArrayList<RemoteRefUpdate>();
 		for (final RemoteRefUpdate u : refUpdates.values()) {
 			final String n = u.getRemoteName();
-			if (!n.startsWith("refs/") || !Repository.isValidRefName(n)) {
+			if (!n.startsWith("refs/") || !Repository.isValidRefName(n)) { //$NON-NLS-1$
 				u.setStatus(Status.REJECTED_OTHER_REASON);
 				u.setMessage(JGitText.get().funnyRefname);
 				continue;
@@ -239,10 +239,10 @@ class WalkPushConnection extends BaseConnection implements PushConnection {
 			for (final String n : dest.getPackNames())
 				packNames.put(n, n);
 
-			final String base = "pack-" + writer.computeName().name();
-			final String packName = base + ".pack";
-			pathPack = "pack/" + packName;
-			pathIdx = "pack/" + base + ".idx";
+			final String base = "pack-" + writer.computeName().name(); //$NON-NLS-1$
+			final String packName = base + ".pack"; //$NON-NLS-1$
+			pathPack = "pack/" + packName; //$NON-NLS-1$
+			pathIdx = "pack/" + base + ".idx"; //$NON-NLS-1$ //$NON-NLS-2$
 
 			if (packNames.remove(packName) != null) {
 				// The remote already contains this pack. We should
@@ -256,8 +256,8 @@ class WalkPushConnection extends BaseConnection implements PushConnection {
 			// Write the pack file, then the index, as readers look the
 			// other direction (index, then pack file).
 			//
-			final String wt = "Put " + base.substring(0, 12);
-			OutputStream os = dest.writeFile(pathPack, monitor, wt + "..pack");
+			final String wt = "Put " + base.substring(0, 12); //$NON-NLS-1$
+			OutputStream os = dest.writeFile(pathPack, monitor, wt + "..pack"); //$NON-NLS-1$
 			try {
 				os = new SafeBufferedOutputStream(os);
 				writer.writePack(monitor, monitor, os);
@@ -265,7 +265,7 @@ class WalkPushConnection extends BaseConnection implements PushConnection {
 				os.close();
 			}
 
-			os = dest.writeFile(pathIdx, monitor, wt + "..idx");
+			os = dest.writeFile(pathIdx, monitor, wt + "..idx"); //$NON-NLS-1$
 			try {
 				os = new SafeBufferedOutputStream(os);
 				writer.writeIndex(os);
@@ -354,7 +354,7 @@ class WalkPushConnection extends BaseConnection implements PushConnection {
 	private void createNewRepository(final List<RemoteRefUpdate> updates)
 			throws TransportException {
 		try {
-			final String ref = "ref: " + pickHEAD(updates) + "\n";
+			final String ref = "ref: " + pickHEAD(updates) + "\n"; //$NON-NLS-1$ //$NON-NLS-2$
 			final byte[] bytes = Constants.encode(ref);
 			dest.writeFile(ROOT_DIR + Constants.HEAD, bytes);
 		} catch (IOException e) {
@@ -362,8 +362,8 @@ class WalkPushConnection extends BaseConnection implements PushConnection {
 		}
 
 		try {
-			final String config = "[core]\n"
-					+ "\trepositoryformatversion = 0\n";
+			final String config = "[core]\n" //$NON-NLS-1$
+					+ "\trepositoryformatversion = 0\n"; //$NON-NLS-1$
 			final byte[] bytes = Constants.encode(config);
 			dest.writeFile(ROOT_DIR + Constants.CONFIG, bytes);
 		} catch (IOException e) {
