@@ -51,8 +51,8 @@ import java.util.List;
 abstract class FS_POSIX extends FS {
 	@Override
 	protected File discoverGitPrefix() {
-		String path = SystemReader.getInstance().getenv("PATH");
-		File gitExe = searchPath(path, "git");
+		String path = SystemReader.getInstance().getenv("PATH"); //$NON-NLS-1$
+		File gitExe = searchPath(path, "git"); //$NON-NLS-1$
 		if (gitExe != null)
 			return gitExe.getParentFile().getParentFile();
 
@@ -62,7 +62,7 @@ abstract class FS_POSIX extends FS {
 			// login shell and search using that.
 			//
 			String w = readPipe(userHome(), //
-					new String[] { "bash", "--login", "-c", "which git" }, //
+					new String[] { "bash", "--login", "-c", "which git" }, // //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$
 					Charset.defaultCharset().name());
 			if (w == null || w.length() == 0)
 				return null;
@@ -91,9 +91,9 @@ abstract class FS_POSIX extends FS {
 	@Override
 	public ProcessBuilder runInShell(String cmd, String[] args) {
 		List<String> argv = new ArrayList<String>(4 + args.length);
-		argv.add("sh");
-		argv.add("-c");
-		argv.add(cmd + " \"$@\"");
+		argv.add("sh"); //$NON-NLS-1$
+		argv.add("-c"); //$NON-NLS-1$
+		argv.add(cmd + " \"$@\""); //$NON-NLS-1$
 		argv.add(cmd);
 		argv.addAll(Arrays.asList(args));
 		ProcessBuilder proc = new ProcessBuilder();
